# HistoryV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**creation_method** | **str** |  | [optional] 
**completion_date** | [**CompletionDateV20**](CompletionDateV20.md) |  | [optional] 
**submission_date** | [**SubmissionDateV20**](SubmissionDateV20.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**claimed** | **bool** |  | [optional] 
**source** | [**SourceV20**](SourceV20.md) |  | [optional] 
**deactivation_date** | [**DeactivationDateV20**](DeactivationDateV20.md) |  | [optional] 
**verified_email** | **bool** |  | [optional] 
**verified_primary_email** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

